
#include "ks0108.h"
#include "project.h"
#include "ugui.h"
#include "ugui_config.h"


uint8 GlcdFlushFlag = 1;

uint8_t ui8LcdRamBuf[NO_OF_LCD_ROWS][NO_OF_LCD_COLMS];
uint8_t ui8LcdDispBuf[NO_OF_LCD_ROWS][NO_OF_LCD_COLMS];
   

void InitGLCDDriver(void)
{      

    RESET_Write(HIGH);			
    LCD_CHIP_SELECT_1();                    //Select IC1
    vLcdComand(DISPLAY_ON);	

}


void vLcdComand(uint8_t ui8Command)
{   
	WRITE_INSTRUCTION();
    READ_WRITE_OFF();
	vLcdDataWrite(ui8Command);
	ENABLE_HIGH();
    CyDelay(DATA_DELAY);
	ENABLE_LOW();
    CyDelay(DATA_DELAY);
}


void vLcdDisplayData(uint8_t ui8Value)
{   
	WRITE_DATA();
    READ_WRITE_OFF();
	vLcdDataWrite(ui8Value);
	ENABLE_HIGH();
	CyDelay(DATA_DELAY);
	ENABLE_LOW();
	CyDelay(DATA_DELAY);
}


void vLcdDataWrite(uint8_t ui8Value)
{   
   
    DB_0_Write(LOW);
    DB_1_Write(LOW);
    DB_2_Write(LOW);
    DB_3_Write(LOW);
    DB_4_Write(LOW);
    DB_5_Write(LOW);
    DB_6_Write(LOW);
    DB_7_Write(LOW);

		if(ui8Value & 0x01)
			DB_0_Write(HIGH);
		if(ui8Value & 0x02)
			DB_1_Write(HIGH);
		if(ui8Value & 0x04)
			DB_2_Write(HIGH);
		if(ui8Value & 0x08)
			DB_3_Write(HIGH);
		if(ui8Value & 0x10)
			DB_4_Write(HIGH);
		if(ui8Value & 0x20)
			DB_5_Write(HIGH);
		if(ui8Value & 0x40)
			DB_6_Write(HIGH);
		if(ui8Value & 0x80)
			DB_7_Write(HIGH);
           
}

void vLcdSetPixel(UG_S16 ui8X, UG_S16 ui8Y, UG_COLOR ui32Color)
{         
	uint8_t  ui8Row, ui8Col;
	uint8_t temp;
	ui8Row = ui8Y>>3;
	ui8Col= ui8X;
	temp = ui8LcdRamBuf[ui8Row][ui8Col];
	if (ui32Color) {
		ui8LcdRamBuf[ui8Row][ui8Col] |= 1 << ( ui8Y & 7);            //Set bit
	} else {
		ui8LcdRamBuf[ui8Row][ui8Col] &= ~(1 << ( ui8Y & 7));         //Clear bit
	}
	if(temp != ui8LcdRamBuf[ui8Row][ui8Col]) {
		GlcdFlushFlag = 1;
	}
}

void GLcdUpdateMain(void)
{
    uint32_t i, j;
    if (GlcdFlushFlag) {
        for(i = 0; i < 8 ; i++) {
            for(j = 0; j < 128; j++) {
                if(ui8LcdDispBuf[i][j] != ui8LcdRamBuf[i][j]) {
                    ui8LcdDispBuf[i][j] = ui8LcdRamBuf[i][j];
                    
                    if (j < 64) {
                        LCD_CHIP_SELECT_1();						//Select IC1
                        SET_COL_NO(j);
                    } else {
                        LCD_CHIP_SELECT_2();						//Select IC2
                        SET_COL_NO(j - 64);
                    }
                    SET_PAGE_NO(i);
                    SET_Z_ADDR(0);
                    vLcdComand(DISPLAY_ON);
                    vLcdDisplayData(ui8LcdDispBuf[i][j]);
                }
            }
        }         
        GlcdFlushFlag = 0;
    }
}

void vLcdPinsLow(void)
{
    DB_0_Write(LOW);
    DB_1_Write(LOW);
    DB_2_Write(LOW);
    DB_3_Write(LOW);
    DB_4_Write(LOW);
    DB_5_Write(LOW);
    DB_6_Write(LOW);
    DB_7_Write(LOW);
}




/* [] END OF FILE */
